%% Second Order Stable Step Responses

%% Stable Responses
Gs1 = tf(10,[1 11 10]);
Gs2 = tf(9,[1 6 9]);
Gs3 = tf(10,[1 2 10]);
Gs = [Gs1; Gs2; Gs3];


% Plot step response for each system
co = get(groot,'defaultAxesColorOrder');
t=linspace(0,5,100);

figure(1);
clf;
for i=1:size(Gs,1)
    [y,t]=step(Gs(i),t);
    plot(t,y,'Color',co(i,:));
    hold on;
end
xlabel('Time (sec)')
ylabel('Unit Step Response')
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

% Add inset figure showing roots in complex plane
axes('position',[0.5 0.28 0.46 0.31])
for i=1:size(Gs,1)
    s = pole(Gs(i));
    if abs(s(1)-s(2))<1e-5
        % Shift repeated poles slightly so they appear as double root
        plot([1.04; 0.96].*real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    else
        plot(real(s),imag(s),'x','Color',co(i,:),...
            'MarkerSize',12);
    end
    hold on;
end
grid
xlabel('Real');
ylabel('Imag');
set(gca,'XTick',[-10 -6 -3 -1 0],'YTick',[-5 -3 0 3 5])
axis([-11 0.5 -5 5]);
ax = axis;
phAx(1)=plot([ax(1) ax(2)],[0 0],'k');
phAx(2)=plot([0 0],[ax(3) ax(4)],'k');

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(phAx,'LineWidth',1);
    myprint(1,'SOStepStable')
end
