%% Underdamped Roots
% Definition of natural frequency, damping ratio, and damped natural
% frequency for underdamped (complex) roots.

%% Define complex number
s = 6+4j;

%% Quantities Associated with Complex Root

% Real / Imaginary Parts
re = real(s);
im = imag(s);

% Polar form
mag = abs(s);
phi = angle(s);

%% Plot 

% Plot Roots
figure(1)
clf;
plot(re,im,'rx','MarkerSize',14);
hold on;
xlabel('Real');
ylabel('Imag');

% Lines for axes and from origin to roots
ax=[-3.8 8.8 -2 5];
axis(ax);
ph(1)=plot(0.97*[0 re],0.97*[0,im],'k:');
ph(2)=plot([0 0],ax(3:4),'k');
ph(3)=plot(ax(1:2),[0 0],'k');

% Text Labels
th(1) = text(0.35*re,0.65*im,'|s|','FontSize',18);
ph(4)=plot([re re],0.25*[-1 1],'k');
th(2) = text(re,-0.5,'a','FontSize',18,...
    'HorizontalAlignment','Center');
ph(5)=plot(0.2*[-1 1],[im im],'k');
ph(6)=plot(0.2*[-1 1],[-im -im],'k');
th(3) = text(-0.85,1*im,'b','FontSize',18);

theta = linspace(0.05,phi-0.05,25);
ph(7)= plot(3*cos(theta),3*sin(theta),'k');
th(4) = text(3,1.1,'\phi','FontSize',18);

%axis equal
set(gca,'Xtick',[],'Ytick',[]);
hold off;

if exist('garyfyFigure','file') && exist('matlab2tikz','file');
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(ph,'LineWidth',1.5)
    for i=1:numel(th)
        set(th(i),'String',['$' get(th(i),'String') '$']);
    end
    
    warning('Not Saving File')
    % To add arrowheads: \addplot[<->,...   
%     matlab2tikz('ComplexNumbers.tikz','width','\figurewidth',...
%         'parseStrings',false,'extraAxisOptions',...
%         'ylabel near ticks, xlabel near ticks');
end

%% Complex Function
% Consider a complex function G(s). Since s and G(s) are both complex
% numbers it is difficult to  visualize this function.  This file 
% generates a plot of the magnitude of G(s) for each complex value of s.

% Real/Imaginary parts of "s" used in plot
Npts = 40;
Re=linspace(-1,3,Npts); 
Im = linspace(-2,2,Npts);

% Compute G(s) for each value of s
G = zeros(Npts,Npts);
for i1=1:Npts
    for i2=1:Npts
        s=Re(i1)+j*Im(i2); 
        G(i2,i1) = 1/(s-2); 
    end,
end

% Plot the magnitude of G
% Notice that |G(s)| shoots to infinity when s = 2, i.e Real(s)=2
% and Imag(s)=0.  This plot looks like a tent with a pole placed at
% s=2 holding up the tent.  Thus we say that G(s) has a "pole" at s=2.
figure(2)
mesh(Re,Im,abs(G));
xlabel('Real(s)');
ylabel('Imag(s)');
zlabel('|G(s)|');
axis([-1 3 -2 2 0 10])
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('matlab2tikz','file');
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    myprint(2,'ComplexFunction')    
end